@@ -7,7 +7,8 @@ import email
 import datetime
 from optparse import Values
 
-from weblog.post import Post, PostError, Author
+from weblog.markup import markups
+from weblog.page import Page, Error, Author
 from weblog.publish import load_posts
 from weblog.date import command_date
 from weblog.publish import command_publish
@@ -43,7 +44,7 @@ class TestSimpleLoad(unittest.TestCase):
         self.assertEqual(sorted_list[2].title, 'post3')
 
     def test_load_post_list_encoding_failure(self):
-        self.assertRaises(PostError, load_posts, _test_filename('encoding'),
+        self.assertRaises(Error, load_posts, _test_filename('encoding'),
                           _default_dict())
 
     def test_load_post_list_encoding(self):
@@ -53,52 +54,52 @@ class TestSimpleLoad(unittest.TestCase):
         sorted_list = sorted(post_list)
         self.assertEqual(sorted_list[0].title,
                          u'UTF-8 post \xd6\xc9\xc8\xc4 ...')
-        self.assertEqual(sorted_list[0].content,
+        self.assertEqual(sorted_list[0].body,
                          u'\xd6\xe9\xe8\xe4\n')
         self.assertEqual(sorted_list[1].title,
                          u'latin post \xd6\xc9\xc8\xc4 ...')
-        self.assertEqual(sorted_list[1].content,
+        self.assertEqual(sorted_list[1].body,
                          u'\xd6\xe9\xe8\xe4\n')
 
     def test_load_posts_duplicate(self):
         self.assertRaises(IOError, load_posts, _test_filename('duplicate'),
                           _default_dict())
 
-class TestPost(unittest.TestCase):
+class TestPage(unittest.TestCase):
     def test_empty(self):
-        self.assertRaises(ValueError, Post)
+        self.assertRaises(ValueError, Page)
 
     def test_simple(self):
         sample_post = ('title: test\ndate: 2008-1-1\nauthor: test author\n'
                        'encoding: ascii\n\ntest.')
-        post = Post(content=sample_post)
+        post = Page(content=sample_post)
         self.assertEqual(post.title, u'test')
         self.assertEqual(post.date, datetime.date(2008, 1, 1))
         self.assertEqual(post.author, u'test author')
         self.assertEqual(post.encoding, 'ascii')
-        self.assertEqual(post.content, u'test.')
+        self.assertEqual(post.body, u'test.')
 
     def test_encoding(self):
         sample_post = (u'title: Test UTF-8 \xdcTF-8 ?\n'
                        u'author: Henry Pr\xeacheur <henry@precheur.org>\n'
                        u'encoding: utf8\n\n'
                        u'blah \xdcTF-8.').encode('utf8') # convert to str
-        post = Post(content=sample_post)
+        post = Page(content=sample_post)
         self.assertEqual(post.title, u'Test UTF-8 \xdcTF-8 ?')
         self.assertEqual(post.author,
                          u'Henry Pr\xeacheur <henry@precheur.org>')
         self.assertEqual(post.encoding, u'utf8')
-        self.assertEqual(post.content, u'blah \xdcTF-8.')
+        self.assertEqual(post.body, u'blah \xdcTF-8.')
 
     def test_no_title(self):
-        self.assertRaises(PostError, Post, content='No title in this post')
+        self.assertRaises(Error, Page, content='No title in this post')
 
     def test_no_payload(self):
         try:
-            Post(content='title: no payload\ndate: 2008-1-1')
-        except PostError, e:
+            Page(content='title: no payload\ndate: 2008-1-1')
+        except Error, e:
             self.assertEqual(e.args,
-                             ('<unknown filename>: no content',))
+                             ('<unknown filename>: no body',))
         else:
             self.failUnless(False) # Should not be there
 
@@ -106,30 +107,30 @@ class TestPost(unittest.TestCase):
         sample_post = ('title: bad encoding\ndate: 2008-1-1\n'
                        'encoding: bad-encoding\n\ntest')
         try:
-            Post(content=sample_post)
-        except PostError, e:
+            Page(content=sample_post)
+        except Error, e:
             self.assertEqual(e.args,
                              ('<unknown filename>: unknown encoding: '
                               'bad-encoding',))
         else:
             self.failUnless(False) # Should not be there
-        self.assertRaises(PostError, Post, content=sample_post)
+        self.assertRaises(Error, Page, content=sample_post)
 
     def test_empty_author(self):
-        post = Post(content='title: test\n\ntest')
+        post = Page(content='title: test\n\ntest')
         self.assertEqual(post.author, u'')
         self.assertEqual(post.author.name(), u'')
         self.assertEqual(post.author.email(), u'')
 
     def test_default_author(self):
-        post = Post(content='title: test\n\ntest',
+        post = Page(content='title: test\n\ntest',
                     default_author=u'Test <test@test.org>')
         self.assertEqual(post.author, u'Test <test@test.org>')
         self.assertEqual(post.author.name(), u'Test')
         self.assertEqual(post.author.email(), u'test@test.org')
 
     def test_author(self):
-        post = Post(content='title:test\nauthor: Test <test@test.org>\n\ntest')
+        post = Page(content='title:test\nauthor: Test <test@test.org>\n\ntest')
         self.assertEqual(post.author, u'Test <test@test.org>')
         self.assertEqual(post.author.name(), u'Test')
         self.assertEqual(post.author.email(), u'test@test.org')
@@ -137,8 +138,8 @@ class TestPost(unittest.TestCase):
     def test_bad_date(self):
         sample_post = 'title: bad encoding\ndate: 20 bad date 08-1-1\n\ntest'
         try:
-            Post(content=sample_post)
-        except PostError, e:
+            Page(content=sample_post)
+        except Error, e:
             self.assertEqual(e.args,
                              ("<unknown filename>: Unable to parse date "
                               "'20 bad date 08-1-1'\n"
@@ -147,34 +148,44 @@ class TestPost(unittest.TestCase):
             self.failUnless(False) # Should not be there
 
     def test_file_no_date(self):
-        p = Post(_test_filename('date/no_date.txt'))
+        p = Page(_test_filename('date/no_date.txt'))
         self.assert_(p.date)
         self.assert_(isinstance(p.date, datetime.date))
 
-    def test_markdown(self):
-        sample_post = ('title: markdown\ndate: 2008-9-12\nmarkup: markdown\n\n'
-                       '*boo*\n\n----\nblah')
-        post = Post(content=sample_post)
-        self.assertEqual(post.get_html(), (u'<p><em>boo</em></p>\n\n'
-                                           '<hr>\n\n<p>blah</p>\n'))
-        self.assertEqual(post.get_xhtml(), (u'<p><em>boo</em></p>\n\n'
-                                            '<hr />\n\n<p>blah</p>\n'))
+    def test_html_markup(self):
+        p = Page(content='title: html\nmarkup: html\n\n<p>html<br>test</p>')
+        self.assertEqual(p.get_html(), u'<p>html<br>test</p>')
+        self.assertEqual(p.get_xhtml(), u'<p>html<br />test</p>')
 
-    def test_html(self):
-        sample_post = 'title: markdown\ndate: 2008-9-12\n\n<p>boo<br>blah</p>'
-        post = Post(content=sample_post)
-        self.assertEqual(post.get_html(), u'<p>boo<br>blah</p>')
-        self.assertEqual(post.get_xhtml(), u'<p>boo<br />blah</p>')
+    if 'markdown' in markups:
+        def test_markdown_markup(self):
+            p = Page(content=('title: markdown\nmarkup: markdown\n\n'
+                              '*boo*\n\n---'))
+            self.assertEqual(p.get_html(), u'<p><em>boo</em></p>\n\n<hr>\n')
+            self.assertEqual(p.get_xhtml(), u'<p><em>boo</em></p>\n\n<hr />\n')
+
+    if 'restructuredtext' in markups:
+        def test_restructuredtext_markup(self):
+            p = Page(content=('title: rst\nmarkup: restructuredtext\n\n'
+                              '*boo*\n\n.. image:: images/biohazard.png'))
+            self.assertEqual(p.get_html(),
+                             u'<p><em>boo</em></p>\n'
+                             u'<img alt="images/biohazard.png" '
+                             u'src="images/biohazard.png" />\n')
+            self.assertEqual(p.get_xhtml(),
+                             u'<p><em>boo</em></p>\n'
+                             u'<img alt="images/biohazard.png" '
+                             u'src="images/biohazard.png" />\n')
 
     def test_cmp(self):
         file1 = 'title: 1\ndate: 2008-1-1\n\ntest'
-        post1 = Post(content=file1)
-        post2 = Post(content='title: 2\ndate: 2007-12-31\n\ntest')
+        post1 = Page(content=file1)
+        post2 = Page(content='title: 2\ndate: 2007-12-31\n\ntest')
         self.assert_(post1 > post2)
         self.assertNotEqual(post1, post2)
         self.assertEqual(post1, post1)
-        self.assertEqual(post1, Post(content=file1))
-        self.assertEqual([post2, post1].index(Post(content=file1)), 1)
+        self.assertEqual(post1, Page(content=file1))
+        self.assertEqual([post2, post1].index(Page(content=file1)), 1)
 
 
 class TempDirMixin(object):
@@ -300,6 +311,11 @@ class TestUrlParser(unittest.TestCase):
                                                         'foo?a=1&b=2')]),
                          u'href="foo?a=1&amp;b=2"')
 
+    def test_anchor(self):
+        '''Anchors shouldn't be rewritten.'''
+        self.assertEqual(FullUrlHtmlParser.html_attrs([('href', '#foo')]),
+                         u'href="#foo"')
+
     def test_utf8_html_parser_attrs(self):
         self.assertEqual(UTF8HTMLParser.html_attrs([('alt',
                                                      'quote """')]),
