@@ -1,8 +1,8 @@
 __author__ = u'Henry Pr\u00EAcheur <henry@precheur.org>'
-__version__ = '2.4'
+__version__ = '2.5'
 __license__ = 'ISCL'
 
-def main():
+def main(args=None):
     import logging
     from optparse import OptionParser, SUPPRESS_HELP
 
@@ -11,7 +11,8 @@ def main():
 
     _COMMANDS = ('publish', 'date')
 
-    parser = OptionParser()
+    parser = OptionParser(usage=('%%prog [option] command\n\nCommands:\n  ' +
+                                 '\n  '.join(_COMMANDS)))
     parser.add_option("-s", "--source_dir", dest="source_dir",
                       default='',
                       help='The source directory where the blog posts are '
@@ -37,9 +38,7 @@ def main():
     parser.add_option('--debug',
                       dest='debug', default=False, action='store_true',
                       help=SUPPRESS_HELP)
-    parser.set_usage('%%prog [option] command\n\nCommands:\n  %s' % \
-                     '\n  '.join(_COMMANDS))
-    (options, args) = parser.parse_args()
+    (options, args) = parser.parse_args(args)
 
     if options.debug:
         logging.basicConfig(level=logging.DEBUG,
@@ -61,20 +60,3 @@ def main():
         command_publish(args, options)
     elif command == 'date':
         command_date(args)
-
-def test_main():
-    import doctest
-    import utils
-    import post
-    import listing
-    import html_full_url
-    import date
-    doctest.testmod(utils)
-    doctest.testmod(post)
-    doctest.testmod(listing)
-    doctest.testmod(html_full_url)
-    doctest.testmod(date)
-    doctest.testmod()
-
-if __name__ == '__main__':
-    test_main()
