@@ -2,7 +2,7 @@ import logging
 import codecs
 import locale
 
-from weblog.post import Author
+from weblog.page import Author
 
 def _default(config, key, default):
     if key not in config:
@@ -23,9 +23,9 @@ def read(filename):
         raise
     del config['__builtins__'] # clean-up the dictionnary
 
-    config['author'] = Author(config.get('author') or '')
+    config['author'] = Author(config.get('author', ''))
     if 'url' not in config:
-        logging.warning('There is no url parameter in "%s". Them atom feed '
+        logging.warning('There is no url parameter in "%s". The atom feed '
                         'will be incorrectly generated.' % filename)
         config['url'] = '/'
     _encoding('encoding', config)
