@@ -1,29 +1,6 @@
-import re
+from urlparse import urljoin
 from utf8_html_parser import UTF8HTMLParser
 
-# Ignore http:// ftp:// mailto: javascript: ...
-_scheme_regex = re.compile(r'\w+:')
-
-def internal_url(url):
-    '''
-    Returns True if ``url`` refers to an external resource.
-
-    >>> internal_url('http://www.google.ca/')
-    False
-    >>> internal_url('mailto:me@example.com')
-    False
-    >>> internal_url('javascript:return false;')
-    False
-    >>> internal_url('/pic.jpg')
-    True
-    >>> internal_url('')
-    True
-    '''
-    if _scheme_regex.match(url):
-        return False
-    else:
-        return True
-
 class FullUrlHtmlParser(UTF8HTMLParser):
     '''
     Parse an HTML document and transform relative URI to absolute URI.
@@ -66,7 +43,7 @@ class FullUrlHtmlParser(UTF8HTMLParser):
 
     def __init__(self, base_url):
         UTF8HTMLParser.__init__(self)
-        self.base_url = base_url.rstrip('/')
+        self.base_url = base_url if base_url[-1] == '/' else base_url + '/'
 
     def make_full_url(self, attr, attrs):
         '''
@@ -77,10 +54,15 @@ class FullUrlHtmlParser(UTF8HTMLParser):
         (('src', 'http://www.example.com/page'), ('foo', 'bar'))
         >>> tuple(p.make_full_url('src', tuple()))
         ()
+
+        Note that anchors are not rewritten.
+
+        >>> tuple(p.make_full_url('href', [('href', '#foo')]))
+        (('href', '#foo'),)
         '''
         for key, value in attrs:
-            if key == attr and internal_url(value):
-                yield (key, self.base_url + '/' + value)
+            if key == attr and not value.startswith('#'):
+                yield(key, urljoin(self.base_url, value))
             else:
                 yield (key, value)
 
